==> jsgantt-improved-2.0.4.jar: META-INF/resources/webjars/jsgantt-improved/2.0.4/src/lang.ts <==
const es = {
  'january': 'Enero',
  'february': 'Febrero',
  'march': 'Marzo',
  'april': 'Abril',
  'maylong': 'Mayo',
  'june': 'Junio',
  'july': 'Julio',
  'august': 'Agosto',
  'september': 'Septiembre',
  'october': 'Octubre',
  'november': 'Noviembre',
  'december': 'Diciembre',
  'jan': 'Ene',
  'feb': 'Feb',
  'mar': 'Mar',
  'apr': 'Abr',
  'may': 'May',
  'jun': 'Jun',
  'jul': 'Jul',
  'aug': 'Ago',
  'sep': 'Sep',
  'oct': 'Oct',
  'nov': 'Nov',
  'dec': 'Dic',
  'sunday': 'Domingo',
  'monday': 'Lunes',
  'tuesday': 'Martes',
  'wednesday': 'Miércoles',
  'thursday': 'Jueves',
  'friday': 'Viernes',
  'saturday': 'Sábado',
  'sun': '	Dom',
  'mon': '	Lun',
  'tue': '	Mar',
  'wed': '	Mie',
  'thu': '	Jue',
  'fri': '	Vie',
  'sat': '	Sab',
  'resource': 'Recurso',
  'duration': 'Duración',
  'comp': '% Completado',
  'completion': 'Terminado',
  'startdate': 'Inicio',
  'planstartdate': 'Inicio Plan',
  'cost': 'Custo',
  'enddate': 'Fin',
  'planenddate': 'Plan Fin',
  'moreinfo': '+información',
  'notes': 'Notas',
  'format': 'Formato',
  'hour': 'Hora',
  'day': 'Dia',
  'week': 'Semana',
  'month': 'Mes',
  'quarter': 'Trimestre',
  'hours': 'Horas',
  'days': 'Días',
  'weeks': 'Semanas',
  'months': 'Meses',
  'quarters': 'Trimestres',
  'hr': 'Hr',
  'dy': 'D',
  'wk': 'Sem',
  'mth': 'Mes',
  'qtr': 'Trim',
  'hrs': 'Hrs',
  'dys': 'Dias',
  'wks': 'Sems',
  'mths': 'Meses',
  'qtrs': 'Trims'
};

const en =
{
  'format': 'Format',
  'hour': 'Hour',
  'day': 'Day',
  'week': 'Week',
  'month': 'Month',
  'quarter': 'Quarter',
  'hours': 'Hours',
  'days': 'Days',
  'weeks': 'Weeks',
  'months': 'Months',
  'quarters': 'Quarters',
  'hr': 'Hr',
  'dy': 'Day',
  'wk': 'Wk',
  'mth': 'Mth',
  'qtr': 'Qtr',
  'hrs': 'Hrs',
  'dys': 'Days',
  'wks': 'Wks',
  'mths': 'Mths',
  'qtrs': 'Qtrs',
  'resource': 'Resource',
  'duration': 'Duration',
  'comp': '% Comp.',
  'completion': 'Completion',
  'startdate': 'Start Date',
  'planstartdate': 'Plan Start Date',
  'enddate': 'End Date',
  'planenddate': 'Plan End Date',
  'cost': 'Cost',
  'moreinfo': 'More Information',
  'notes': 'Notes',
  'january': 'January',
  'february': 'February',
  'march': 'March',
  'april': 'April',
  'maylong': 'May',
  'june': 'June',
  'july': 'July',
  'august': 'August',
  'september': 'September',
  'october': 'October',
  'november': 'November',
  'december': 'December',
  'jan': 'Jan',
  'feb': 'Feb',
  'mar': 'Mar',
  'apr': 'Apr',
  'may': 'May',
  'jun': 'Jun',
  'jul': 'Jul',
  'aug': 'Aug',
  'sep': 'Sep',
  'oct': 'Oct',
  'nov': 'Nov',

  'dec': 'Dec',
  'sunday': 'Sunday',
  'monday': 'Monday',
  'tuesday': 'Tuesday',
  'wednesday': 'Wednesday',
  'thursday': 'Thursday',

  'friday': 'Friday',
  'saturday': 'Saturday',
  'sun': 'Sun',
  'mon': 'Mon',
  'tue': 'Tue',
  'wed': 'Wed',
  'thu': 'Thu',
  'fri': 'Fri',
  'sat': 'Sat'
}

const de = {
  'format': 'Ansicht',
  'hour': 'Stunde',
  'day': 'Tag',
  'week': 'Woche',
  'month': 'Monat',
  'quarter': 'Quartal',
  'hours': 'Stunden',
  'days': 'Tage',
  'weeks': 'Wochen',
  'months': 'Monate',
  'quarters': 'Quartale',
  'hr': 'h',
  'dy': 'T',
  'wk': 'W',
  'mth': 'M',
  'qtr': 'Q',
  'hrs': 'Std',
  'dys': 'Tage',
  'wks': 'Wochen',
  'mths': 'Monate',
  'qtrs': 'Quartal',
  'resource': 'Resource',
  'duration': 'Dauer',
  'comp': '%Fertig',
  'completion': 'Fertigstellung',
  'startdate': 'Erste Buchu',
  'planstartdate': 'Erste Buchu Plan',
  'enddate': 'Letzte Buchung',
  'planenddate': 'Plan Letzte Buchung',
  'cost': 'Cost',
  'moreinfo': 'Weitere Infos',
  'notes': 'Anmerkung',
  'january': 'Jänner',
  'february': 'Februar',
  'march': 'März',
  'april': 'April',
  'maylong': 'Mai',
  'june': 'Juni',
  'july': 'Juli',
  'august': 'August',
  'september': 'September',
  'october': 'Oktober',
  'november': 'November',
  'december': 'Dezember',
  'jan': 'Jan',
  'feb': 'Feb',
  'mar': 'Mar',
  'apr': 'Apr',
  'may': 'Mai',
  'jun': 'Jun',
  'jul': 'Jul',
  'aug': 'Aug',
  'sep': 'Sep',
  'oct': 'Okt',
  'nov': 'Nov',
  'dec': 'Dez',
  'sunday': 'Sonntag',
  'monday': 'Montag',
  'tuesday': 'Dienstag',
  'wednesday': 'Mittwoch',
  'thursday': 'Donnerstag',
  'friday': 'Freitag',
  'saturday': 'Samstag',
  'sun': 'So',
  'mon': 'Mo', 'tue': 'Di', 'wed': 'Mi', 'thu': 'Do', 'fri': 'Fr', 'sat': 'Sa'
}

const pt = {
  'hours': 'Horas',
  'days': 'Dias',
  'weeks': 'Weeks',
  'months': 'Months',
  'quarters': 'Quarters',
  'format': 'Formato',
  'hour': 'Hora',
  'day': 'Dia',
  'week': 'Semana',
  'month': 'Mês',
  'quarter': 'Trimestre',
  'hr': 'hr',
  'dy': 'dia',
  'wk': 'sem.',
  'mth': 'mês',
  'qtr': 'qtr',
  'hrs': 'hrs',
  'dys': 'dias',
  'wks': 'sem.',
  'mths': 'meses',
  'qtrs': 'qtrs',
  'completion': 'Terminado',
  'comp': '% Completado',
  'moreinfo': 'Mais informações',
  'notes': 'Notas',
  'resource': 'Responsável',
  'duration': 'Duração',
  'startdate': 'Data inicial',
  'planstartdate': 'Plan Data inicial',
  'enddate': 'Data final',
  'planenddate': 'Plan Data final',
  'cost': 'Custo',
  'jan': 'Jan',
  'feb': 'Fev',
  'mar': 'Mar',
  'apr': 'Abr',
  'may': 'Mai',
  'jun': 'Jun',
  'jul': 'Jul',
  'aug': 'Ago',
  'sep': 'Set',
  'oct': 'Out',
  'nov': 'Nov',
  'dec': 'Dez',
  'january': 'Janeiro',
  'february': 'Fevereiro',
  'march': 'Março',
  'april': 'Abril',
  'maylong': 'Maio',
  'june': 'Junho',
  'july': 'Julho',
  'august': 'Agosto',
  'september': 'Setembro',
  'october': 'Outubro',
  'november': 'Novembro',
  'december': 'Dezembro',
  'sun': 'Dom',
  'mon': 'Seg',
  'tue': 'Ter',
  'wed': 'Qua',
  'thu': 'Qui',
  'fri': 'Sex',
  'sat': 'Sab'
}

const ru = {
  'january': 'Январь',
  'february': 'Февраль',
  'march': 'Март',
  'april': 'Апрель',
  'maylong': 'Май',
  'june': 'Июнь',
  'july': 'Июль',
  'august': 'Август', 'september': 'Сентябрь',
  'october': 'Октябрь',
  'november': 'Ноябрь',
  'december': 'Декабрь',
  'jan': 'Янв',
  'feb': 'Фев',
  'mar': 'Мар',
  'apr': 'Апр',
  'may': 'Май',
  'jun': 'Июн',
  'jul': 'Июл',
  'aug': 'Авг',
  'sep': 'Сен',
  'oct': 'Окт',
  'nov': 'Ноя',
  'dec': 'Дек',

  'sunday': 'Воскресенье',
  'monday': 'Понедельник',
  'tuesday': 'Вторник',
  'wednesday': 'Среда',
  'thursday': 'Четверг',
  'friday': 'Пятница',
  'saturday': 'Суббота',
  'sun': '	Вс',
  'mon': '	Пн',
  'tue': '	Вт',
  'wed': '	Ср',
  'thu': '	Чт',
  'fri': '	Пт',
  'sat': '	Сб',
  'resource': 'Ресурс',
  'duration': 'Длительность',
  'comp': '% выполнения',
  'completion': 'Выполнено',
  'startdate': 'Нач. дата',
  'planstartdate': 'Plan Нач. дата',
  'enddate': 'Кон. дата',
  'planenddate': 'Plan Кон. дата',
  'cost': 'Cost',
  'moreinfo': 'Детали',
  'notes': 'Заметки',
  'format': 'Формат',
  'hour': 'Час',
  'day': 'День',
  'week': 'Неделя',
  'month': 'Месяц',
  'quarter': 'Кварт',
  'hours': 'Часов',
  'days': 'Дней',
  'weeks': 'Недель',
  'months': 'Месяцев',
  'quarters': 'Кварталов',
  'hr': 'ч.',
  'dy': 'дн.',
  'wk': 'нед.',
  'mth': 'мес.',
  'qtr': 'кв.',
  'hrs': 'ч.',
  'dys': 'дн.',
  'wks': 'нед.',
  'mths': 'мес.',
  'qtrs': 'кв.'
}

const fr = {
  // Mois : http://bdl.oqlf.gouv.qc.ca/bdl/gabarit_bdl.asp?id=3619
  // Jours : http://bdl.oqlf.gouv.qc.ca/bdl/gabarit_bdl.asp?id=3617
  'january': 'Janvier',
  'february': 'Février',
  'march': 'Mars',
  'april': 'Avril',
  'maylong': 'Mai',
  'june': 'Juin',
  'july': 'Juillet',
  'august': 'Août',
  'september': 'Septembre',
  'october': 'Octobre',
  'november': 'Novembre',
  'december': 'Décembre',
  'jan': 'Janv',
  'feb': 'Févr',
  'mar': 'Mars',
  'apr': 'Avr',
  'may': 'Mai',
  'jun': 'Juin',
  'jul': 'Juil',
  'aug': 'Août',
  'sep': 'Sept',
  'oct': 'Oct',
  'nov': 'Nov',
  'dec': 'Déc',
  'sunday': 'Dimanche',
  'monday': 'Lundi',
  'tuesday': 'Mardi',
  'wednesday': 'Mercredi',
  'thursday': 'Jeudi',
  'friday': 'Vendredi',
  'saturday': 'Samedi',
  'sun': 'Dim',
  'mon': 'Lun',
  'tue': 'Mar',
  'wed': 'Mer',
  'thu': 'Jeu',
  'fri': 'Ven',
  'sat': 'Sam',
  'resource': 'Ressource',
  'duration': 'Durée',
  'comp': '% Term.',
  'completion': 'Terminé',
  'startdate': 'Début',
  'planstartdate': 'Plan Début',
  'enddate': 'Fin',
  'planenddate': 'Plan Fin',
  'cost': 'Cost',
  'moreinfo': "Plus d'informations",
  'notes': 'Notes',
  'format': 'Format',
  'hour': 'Heure',
  'day': 'Jour',
  'week': 'Semaine',
  'month': 'Mois',
  'quarter': 'Trimestre',
  'hours': 'Heures',
  'days': 'Jours',
  'weeks': 'Semaines',
  'months': 'Mois',
  'quarters': 'Trimestres',
  'hr': 'h',
  'dy': 'j',
  'wk': 'sem',
  'mth': 'mois',
  'qtr': 'tri',
  'hrs': 'h',
  'dys': 'j',
  'wks': 'sem',
  'mths': 'mois',
  'qtrs': 'tri'
}
export { en, es, de, pt, fr, ru }

==> jsgantt-improved-2.1.2.jar: META-INF/resources/webjars/jsgantt-improved/2.1.2/src/lang.ts <==
const es = {
  'january': 'Enero',
  'february': 'Febrero',
  'march': 'Marzo',
  'april': 'Abril',
  'maylong': 'Mayo',
  'june': 'Junio',
  'july': 'Julio',
  'august': 'Agosto',
  'september': 'Septiembre',
  'october': 'Octubre',
  'november': 'Noviembre',
  'december': 'Diciembre',
  'jan': 'Ene',
  'feb': 'Feb',
  'mar': 'Mar',
  'apr': 'Abr',
  'may': 'May',
  'jun': 'Jun',
  'jul': 'Jul',
  'aug': 'Ago',
  'sep': 'Sep',
  'oct': 'Oct',
  'nov': 'Nov',
  'dec': 'Dic',
  'sunday': 'Domingo',
  'monday': 'Lunes',
  'tuesday': 'Martes',
  'wednesday': 'Miércoles',
  'thursday': 'Jueves',
  'friday': 'Viernes',
  'saturday': 'Sábado',
  'sun': '	Dom',
  'mon': '	Lun',
  'tue': '	Mar',
  'wed': '	Mie',
  'thu': '	Jue',
  'fri': '	Vie',
  'sat': '	Sab',
  'resource': 'Recurso',
  'duration': 'Duración',
  'comp': '% Completado',
  'completion': 'Terminado',
  'startdate': 'Inicio',
  'planstartdate': 'Inicio Plan',
  'cost': 'Custo',
  'enddate': 'Fin',
  'planenddate': 'Plan Fin',
  'moreinfo': '+información',
  'notes': 'Notas',
  'format': 'Formato',
  'hour': 'Hora',
  'day': 'Dia',
  'week': 'Semana',
  'month': 'Mes',
  'quarter': 'Trimestre',
  'hours': 'Horas',
  'days': 'Días',
  'weeks': 'Semanas',
  'months': 'Meses',
  'quarters': 'Trimestres',
  'hr': 'Hr',
  'dy': 'D',
  'wk': 'Sem',
  'mth': 'Mes',
  'qtr': 'Trim',
  'hrs': 'Hrs',
  'dys': 'Dias',
  'wks': 'Sems',
  'mths': 'Meses',
  'qtrs': 'Trims'
};

const en =
{
  'format': 'Format',
  'hour': 'Hour',
  'day': 'Day',
  'week': 'Week',
  'month': 'Month',
  'quarter': 'Quarter',
  'hours': 'Hours',
  'days': 'Days',
  'weeks': 'Weeks',
  'months': 'Months',
  'quarters': 'Quarters',
  'hr': 'Hr',
  'dy': 'Day',
  'wk': 'Wk',
  'mth': 'Mth',
  'qtr': 'Qtr',
  'hrs': 'Hrs',
  'dys': 'Days',
  'wks': 'Wks',
  'mths': 'Mths',
  'qtrs': 'Qtrs',
  'resource': 'Resource',
  'duration': 'Duration',
  'comp': '% Comp.',
  'completion': 'Completion',
  'startdate': 'Start Date',
  'planstartdate': 'Plan Start Date',
  'enddate': 'End Date',
  'planenddate': 'Plan End Date',
  'cost': 'Cost',
  'moreinfo': 'More Information',
  'notes': 'Notes',
  'january': 'January',
  'february': 'February',
  'march': 'March',
  'april': 'April',
  'maylong': 'May',
  'june': 'June',
  'july': 'July',
  'august': 'August',
  'september': 'September',
  'october': 'October',
  'november': 'November',
  'december': 'December',
  'jan': 'Jan',
  'feb': 'Feb',
  'mar': 'Mar',
  'apr': 'Apr',
  'may': 'May',
  'jun': 'Jun',
  'jul': 'Jul',
  'aug': 'Aug',
  'sep': 'Sep',
  'oct': 'Oct',
  'nov': 'Nov',

  'dec': 'Dec',
  'sunday': 'Sunday',
  'monday': 'Monday',
  'tuesday': 'Tuesday',
  'wednesday': 'Wednesday',
  'thursday': 'Thursday',

  'friday': 'Friday',
  'saturday': 'Saturday',
  'sun': 'Sun',
  'mon': 'Mon',
  'tue': 'Tue',
  'wed': 'Wed',
  'thu': 'Thu',
  'fri': 'Fri',
  'sat': 'Sat'
}

const de = {
  'format': 'Ansicht',
  'hour': 'Stunde',
  'day': 'Tag',
  'week': 'Woche',
  'month': 'Monat',
  'quarter': 'Quartal',
  'hours': 'Stunden',
  'days': 'Tage',
  'weeks': 'Wochen',
  'months': 'Monate',
  'quarters': 'Quartale',
  'hr': 'h',
  'dy': 'T',
  'wk': 'W',
  'mth': 'M',
  'qtr': 'Q',
  'hrs': 'Std',
  'dys': 'Tage',
  'wks': 'Wochen',
  'mths': 'Monate',
  'qtrs': 'Quartal',
  'resource': 'Resource',
  'duration': 'Dauer',
  'comp': '%Fertig',
  'completion': 'Fertigstellung',
  'startdate': 'Erste Buchu',
  'planstartdate': 'Erste Buchu Plan',
  'enddate': 'Letzte Buchung',
  'planenddate': 'Plan Letzte Buchung',
  'cost': 'Cost',
  'moreinfo': 'Weitere Infos',
  'notes': 'Anmerkung',
  'january': 'Jänner',
  'february': 'Februar',
  'march': 'März',
  'april': 'April',
  'maylong': 'Mai',
  'june': 'Juni',
  'july': 'Juli',
  'august': 'August',
  'september': 'September',
  'october': 'Oktober',
  'november': 'November',
  'december': 'Dezember',
  'jan': 'Jan',
  'feb': 'Feb',
  'mar': 'Mar',
  'apr': 'Apr',
  'may': 'Mai',
  'jun': 'Jun',
  'jul': 'Jul',
  'aug': 'Aug',
  'sep': 'Sep',
  'oct': 'Okt',
  'nov': 'Nov',
  'dec': 'Dez',
  'sunday': 'Sonntag',
  'monday': 'Montag',
  'tuesday': 'Dienstag',
  'wednesday': 'Mittwoch',
  'thursday': 'Donnerstag',
  'friday': 'Freitag',
  'saturday': 'Samstag',
  'sun': 'So',
  'mon': 'Mo', 'tue': 'Di', 'wed': 'Mi', 'thu': 'Do', 'fri': 'Fr', 'sat': 'Sa'
}

const pt = {
  'hours': 'Horas',
  'days': 'Dias',
  'weeks': 'Weeks',
  'months': 'Months',
  'quarters': 'Quarters',
  'format': 'Formato',
  'hour': 'Hora',
  'day': 'Dia',
  'week': 'Semana',
  'month': 'Mês',
  'quarter': 'Trimestre',
  'hr': 'hr',
  'dy': 'dia',
  'wk': 'sem.',
  'mth': 'mês',
  'qtr': 'qtr',
  'hrs': 'hrs',
  'dys': 'dias',
  'wks': 'sem.',
  'mths': 'meses',
  'qtrs': 'qtrs',
  'completion': 'Terminado',
  'comp': '% Completado',
  'moreinfo': 'Mais informações',
  'notes': 'Notas',
  'resource': 'Responsável',
  'duration': 'Duração',
  'startdate': 'Data inicial',
  'planstartdate': 'Plan Data inicial',
  'enddate': 'Data final',
  'planenddate': 'Plan Data final',
  'cost': 'Custo',
  'jan': 'Jan',
  'feb': 'Fev',
  'mar': 'Mar',
  'apr': 'Abr',
  'may': 'Mai',
  'jun': 'Jun',
  'jul': 'Jul',
  'aug': 'Ago',
  'sep': 'Set',
  'oct': 'Out',
  'nov': 'Nov',
  'dec': 'Dez',
  'january': 'Janeiro',
  'february': 'Fevereiro',
  'march': 'Março',
  'april': 'Abril',
  'maylong': 'Maio',
  'june': 'Junho',
  'july': 'Julho',
  'august': 'Agosto',
  'september': 'Setembro',
  'october': 'Outubro',
  'november': 'Novembro',
  'december': 'Dezembro',
  'sun': 'Dom',
  'mon': 'Seg',
  'tue': 'Ter',
  'wed': 'Qua',
  'thu': 'Qui',
  'fri': 'Sex',
  'sat': 'Sab'
}

const ru = {
  'january': 'Январь',
  'february': 'Февраль',
  'march': 'Март',
  'april': 'Апрель',
  'maylong': 'Май',
  'june': 'Июнь',
  'july': 'Июль',
  'august': 'Август', 'september': 'Сентябрь',
  'october': 'Октябрь',
  'november': 'Ноябрь',
  'december': 'Декабрь',
  'jan': 'Янв',
  'feb': 'Фев',
  'mar': 'Мар',
  'apr': 'Апр',
  'may': 'Май',
  'jun': 'Июн',
  'jul': 'Июл',
  'aug': 'Авг',
  'sep': 'Сен',
  'oct': 'Окт',
  'nov': 'Ноя',
  'dec': 'Дек',

  'sunday': 'Воскресенье',
  'monday': 'Понедельник',
  'tuesday': 'Вторник',
  'wednesday': 'Среда',
  'thursday': 'Четверг',
  'friday': 'Пятница',
  'saturday': 'Суббота',
  'sun': '	Вс',
  'mon': '	Пн',
  'tue': '	Вт',
  'wed': '	Ср',
  'thu': '	Чт',
  'fri': '	Пт',
  'sat': '	Сб',
  'resource': 'Ресурс',
  'duration': 'Длительность',
  'comp': '% выполнения',
  'completion': 'Выполнено',
  'startdate': 'Нач. дата',
  'planstartdate': 'Plan Нач. дата',
  'enddate': 'Кон. дата',
  'planenddate': 'Plan Кон. дата',
  'cost': 'Cost',
  'moreinfo': 'Детали',
  'notes': 'Заметки',
  'format': 'Формат',
  'hour': 'Час',
  'day': 'День',
  'week': 'Неделя',
  'month': 'Месяц',
  'quarter': 'Кварт',
  'hours': 'Часов',
  'days': 'Дней',
  'weeks': 'Недель',
  'months': 'Месяцев',
  'quarters': 'Кварталов',
  'hr': 'ч.',
  'dy': 'дн.',
  'wk': 'нед.',
  'mth': 'мес.',
  'qtr': 'кв.',
  'hrs': 'ч.',
  'dys': 'дн.',
  'wks': 'нед.',
  'mths': 'мес.',
  'qtrs': 'кв.'
}

const fr = {
  // Mois : http://bdl.oqlf.gouv.qc.ca/bdl/gabarit_bdl.asp?id=3619
  // Jours : http://bdl.oqlf.gouv.qc.ca/bdl/gabarit_bdl.asp?id=3617
  'january': 'Janvier',
  'february': 'Février',
  'march': 'Mars',
  'april': 'Avril',
  'maylong': 'Mai',
  'june': 'Juin',
  'july': 'Juillet',
  'august': 'Août',
  'september': 'Septembre',
  'october': 'Octobre',
  'november': 'Novembre',
  'december': 'Décembre',
  'jan': 'Janv',
  'feb': 'Févr',
  'mar': 'Mars',
  'apr': 'Avr',
  'may': 'Mai',
  'jun': 'Juin',
  'jul': 'Juil',
  'aug': 'Août',
  'sep': 'Sept',
  'oct': 'Oct',
  'nov': 'Nov',
  'dec': 'Déc',
  'sunday': 'Dimanche',
  'monday': 'Lundi',
  'tuesday': 'Mardi',
  'wednesday': 'Mercredi',
  'thursday': 'Jeudi',
  'friday': 'Vendredi',
  'saturday': 'Samedi',
  'sun': 'Dim',
  'mon': 'Lun',
  'tue': 'Mar',
  'wed': 'Mer',
  'thu': 'Jeu',
  'fri': 'Ven',
  'sat': 'Sam',
  'resource': 'Ressource',
  'duration': 'Durée',
  'comp': '% Term.',
  'completion': 'Terminé',
  'startdate': 'Début',
  'planstartdate': 'Plan Début',
  'enddate': 'Fin',
  'planenddate': 'Plan Fin',
  'cost': 'Cost',
  'moreinfo': "Plus d'informations",
  'notes': 'Notes',
  'format': 'Format',
  'hour': 'Heure',
  'day': 'Jour',
  'week': 'Semaine',
  'month': 'Mois',
  'quarter': 'Trimestre',
  'hours': 'Heures',
  'days': 'Jours',
  'weeks': 'Semaines',
  'months': 'Mois',
  'quarters': 'Trimestres',
  'hr': 'h',
  'dy': 'j',
  'wk': 'sem',
  'mth': 'mois',
  'qtr': 'tri',
  'hrs': 'h',
  'dys': 'j',
  'wks': 'sem',
  'mths': 'mois',
  'qtrs': 'tri'
}

const cn = {
  'january': '一月',
  'february': '二月',
  'march': '三月',
  'april': '四月',
  'maylong': '五月',
  'june': '六月',
  'july': '七月',
  'august': '八月',
  'september': '九月',
  'october': '十月',
  'november': '十一月',
  'december': '十二月',
  'jan': '一月',
  'feb': '二月',
  'mar': '三月',
  'apr': '四月',
  'may': '五月',
  'jun': '六月',
  'jul': '七月',
  'aug': '八月',
  'sep': '九月',
  'oct': '十月',
  'nov': '十一月',
  'dec': '十二月',
  'sunday': '星期日',
  'monday': '星期一',
  'tuesday': '星期二',
  'wednesday': '星期三',
  'thursday': '星期四',
  'friday': '星期五',
  'saturday': '星期六',
  'sun': '星期日',
  'mon': '星期一',
  'tue': '星期二',
  'wed': '星期三',
  'thu': '星期四',
  'fri': '星期五',
  'sat': '星期六',
  'resource': '資源',
  'duration': '時程',
  'comp': '達成率',
  'completion': '達成',
  'startdate': '起始日期',
  'planstartdate': '計劃起始日期',
  'enddate': '截止日期',
  'planenddate': '計劃截止日期',
  'cost': '成本',
  'moreinfo': "更多資訊",
  'notes': '備註',
  'format': '格式',
  'hour': '時',
  'day': '日',
  'week': '星期',
  'month': '月',
  'quarter': '季',
  'hours': '小時',
  'days': '天',
  'weeks': '週',
  'months': '月',
  'quarters': '季',
  'hr': '小時',
  'dy': '天',
  'wk': '週',
  'mth': '月',
  'qtr': '季',
  'hrs': '小時',
  'dys': '天',
  'wks': '週',
  'mths': '月',
  'qtrs': '季'
}

export { en, es, de, pt, fr, ru, cn }
